@@ -1,5 +1,6 @@
 import sys
 import os
+
 dir_path = os.path.dirname(os.path.realpath(__file__))
 sys.path.append(os.path.abspath(os.path.join(dir_path, os.pardir)))
 
@@ -124,14 +125,16 @@ def get_data_from_file_col(fpath, text_index: int = 0, label_index: int = 1, sep
 def get_feature_from_data(tokenizer, labels, input, target=None, maxlen=512, separator=" "):
     # ``1`` for tokens that are NOT MASKED, ``0`` for MASKED tokens.
     row_dict = dict()
-    tokenized_input = [tok_begin(tokenizer)] + tokenizer.tokenize(input) + [tok_sep(tokenizer)]
+    # tokenized_input = [tok_begin(tokenizer)] + tokenizer.tokenize(input) + [tok_sep(tokenizer)]
+    tokenized_input = tokenizer.tokenize(input)
     input_id = tokenizer.convert_tokens_to_ids(tokenized_input)
     input = input.split()
     mapping_index = []
 
     pos = 1  # cls as start 0
+    basic_len = len(tokenizer.tokenize("hi")) - 1
     for i in input:
-        for _ in range(len(tokenizer.tokenize(i))):
+        for _ in range(len(tokenizer.tokenize(i)) - basic_len):
             if _ < 1:
                 mapping_index.append({'char': i, 'pos': pos})
             pos += 1
@@ -141,12 +144,12 @@ def get_feature_from_data(tokenizer, labels, input, target=None, maxlen=512, sep
         target_token = []
 
         for i, t in zip(input, target):
-            for _ in range(len(tokenizer.tokenize(i))):
+            for _ in range(len(tokenizer.tokenize(i))-basic_len):
                 target_token += [labels.index(t)]
 
         target_id = [labels.index("O")] + target_token + [labels.index("O")]
         if len(input_id) != len(target_id):
-            print("input target len no equal", len(input), len(target), input, target)
+            print("input target len not equal", len(input), len(target), input, target, input_id, target_id)
         target_id.extend([0] * (maxlen - len(target_id)))
         row_dict['target'] = np.asarray(target_id)
 
